/***************************************************************************//**
 *   @file   ADF4360.h
 *   @brief  Header file of ADF4360 Driver.
 *   @author Bancisor Mihai
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 369
*******************************************************************************/
#ifndef __ADF4360_H__
#define __ADF4360_H__

/******************************************************************************/
/* ADF4360 Latch Control Bits                                                 */
/******************************************************************************/

/* ADF4360 latch control bits  */
#define ADF4360_LATCH_SELECT(x)	(0x3 & (x))
#define ADF4360_CONTROL_LATCH	0
#define ADF4360_N_COUNTER		2
#define ADF4360_R_COUNTER		1

/******************************************************************************/
/* ADF4360 Control Latch                                                      */
/******************************************************************************/

/*ADF4360 Prescaler Value*/
#define ADF4360_CONTROL_PRESCALER_SELECT(x)	((0x3 & (x)) << 22)
#define ADF4360_CONTROL_PRESCALER_8_9		0
#define ADF4360_CONTROL_PRESCALER_16_17		1
#define ADF4360_CONTROL_PRESCALER_32_33		2

/*ADF4360 Powed Down Modes*/  
#define ADF4360_CONTROL_POWER_DOWN_SELECT(x)	((0x3 & (x)) << 20)
#define ADF4360_CONTROL_NORMAL_OPERATION        0
#define ADF4360_CONTROL_ASYNCHRONOUS_POWER_DOWN 1
#define ADF4360_CONTROL_SYNCHRONOUS_POWER_DOWN  3

/*ADF4360 Charge Pump Current 1*/  
#define ADF4360_CONTROL_CP_CURRENT1_SELECT(x)   ((0x7 & (x)) << 17)

/*ADF4360 Charge Pump Current 2*/    
#define ADF4360_CONTROL_CP_CURRENT2_SELECT(x)   ((0x7 & (x)) << 14)

/*ADF4360 Output Power Level*/ 
#define ADF4360_CONTROL_OUTPUT_POWER_SELECT(x)  ((0x3 & (x)) << 12)
#define ADF4360_CONTROL_OUTPUT_POWER_3_5   		0
#define ADF4360_CONTROL_OUTPUT_POWER_5_0        1
#define ADF4360_CONTROL_OUTPUT_POWER_7_5        2
#define ADF4360_CONTROL_OUTPUT_POWER_11_0		3

/*ADF4360 Mute Till Lock Detect*/ 
#define ADF4360_CONTROL_MUTE_LD					(1 << 11)

/*ADF4360 Charge Pump Gain*/ 
#define ADF4360_CONTROL_CP_GAIN   	   			(1 << 10)

/*ADF4360 Charge Pump Three-State*/ 
#define ADF4360_CONTROL_CP_THREE_STATE  		(1 << 9)

/*ADF4360 Phase Detector Polarity*/
#define ADF4360_CONTROL_PHASE_DETECTOR_POLARITY	(1 << 8)

/*ADF4360 Muxout Control*/
#define ADF4360_CONTROL_MUXOUT_SELECT(x)     		((0x7 & (x)) << 5)
#define ADF4360_CONTROL_MUXOUT_THREE_STATE_OUTPUT   0
#define ADF4350_CONTROL_MUXOUT_DIGITAL_LOCK_DETECT  1
#define ADF4350_CONTROL_MUXOUT_N_DIVIDER_OUTPUT     2
#define ADF4350_CONTROL_MUXOUT_DVDD                 3
#define ADF4350_CONTROL_MUXOUT_R_DIVIDER_OUTPUT     4
#define ADF4350_CONTROL_MUXOUT_N_LOCK_DETECT        5
#define ADF4350_CONTROL_MUXOUT_SERIAL_DATA          6
#define ADF4350_CONTROL_MUXOUT_DGND                 7

/*ADF4360 Counter Reset*/
#define AD4360_CONTROL_COUNTER_RESET			(1 << 4)

/*ADF4360 Core Power Level*/ 
#define ADF4360_CONTROL_CORE_POWER_SELECT(x)	((0x3 & (x)) << 2)
#define ADF4360_CONTROL_CORE_POWER_5     		0
#define ADF4360_CONTROL_CORE_POWER_10    		1
#define ADF4360_CONTROL_CORE_POWER_15    		2
#define ADF4360_CONTROL_CORE_POWER_20    		3

/******************************************************************************/
/* ADF4360 N Counter Latch                                                    */
/******************************************************************************/

/*ADF4360 Divide by 2 Select*/
#define ADF4360_N_COUNTER_DIVIDE_2_SELECT	(1 << 23)

/*ADF4360 Divide by 2*/
#define ADF4360_N_COUNTER_DIVIDE_2          (1 << 22)

/*ADF4360 Charge Pump Setting Permanently Used*/
#define ADF4360_N_COUNTER_CP_GAIN           (1 << 21)

/*ADF4360 13 bit B Counter*/ 
#define ADF4360_N_COUNTER_B_COUNTER(x)		((0x1FFF & (x)) << 8)

/*ADF4360 5 bit A Counter*/ 
#define ADF4360_N_COUNTER_A_COUNTER(x)		((0x1F & (x)) << 2) 

/******************************************************************************/
/*  ADF4360 R Counter Latch                                                  */
/******************************************************************************/

/*ADF4360 Band Select Clock Divider*/ 
#define ADF4360_R_COUNTER_BAND_DIVIDER_SELECT(x)	((0x3 & (x)) << 20)
#define ADF4360_R_COUNTER_BAND_DIVIDER_1			0
#define ADF4360_R_COUNTER_BAND_DIVIDER_2			1
#define ADF4360_R_COUNTER_BAND_DIVIDER_4			2
#define ADF4360_R_COUNTER_BAND_DIVIDER_8			3

/*ADF4360 Test Bit*/
#define ADF4360_R_COUNTER_TEST						(1 << 19)

/*ADF4360 Lock Detect Precision*/ 
#define ADF4360_R_COUNTER_LOCK_DETECT_PRECISION		(1 << 18)

/*ADF4360 Anti-Backlash Pulse Width*/ 
#define ADF4360_R_COUNTER_ANTI_BACKLASH_SELECT(x)	((0x3 & (x)) << 16)

/*ADF4360 14-bit Reference Counter*/ 
#define ADF4360_R_COUNTER_REFERENCE_COUNTER(x)		((0x3FFF & (x)) << 2) 

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
void ADF4360_Write3Bytes(unsigned long data);	// Writes data into a register.
unsigned char ADF4360_Init(void);				// Initializes the SPI.

#endif
